@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.014;
 
-our $VERSION = '2.409';
+our $VERSION = '2.410';
 
 use File::Basename        qw( basename );
 use File::Spec::Functions qw( catfile catdir );
@@ -38,7 +38,7 @@ sub new {
     my $info = {
         tc_default    => { hide_cursor => 0, clear_screen => 1, page => 2, keep => 6, undef => '<<', prompt => 'Your choice:' },
         tcu_default   => { hide_cursor => 0, clear_screen => 1, page => 2, keep => 6, confirm => '-OK-', back => '<<' },
-        tf_default    => { hide_cursor => 2, clear_screen => 1, page => 2, keep => 6, auto_up => 1 },
+        tf_default    => { hide_cursor => 2, clear_screen => 1, page => 2, keep => 6, auto_up => 1, skip_items => qr/^\s*\z/ },
         tr_default    => { hide_cursor => 2, clear_screen => 1, page => 2, history => [ 0 .. 1000 ] },
         lyt_h         => { order => 0, alignment => 2 },
         lyt_v         => { undef => '  BACK', layout => 2 },
@@ -639,7 +639,7 @@ App::DBBrowser - Browse SQLite/MySQL/PostgreSQL databases and their tables inter
 
 =head1 VERSION
 
-Version 2.409
+Version 2.410
 
 =head1 DESCRIPTION
 
