@@ -10,7 +10,7 @@ use Encode                qw( encode decode );
 use File::Basename        qw( basename );
 use File::Spec::Functions qw( catfile catdir );
 
-use List::MoreUtils qw( uniq );
+use List::MoreUtils qw( uniq firstidx );
 use Encode::Locale  qw();
 
 use Term::Choose           qw();
@@ -59,7 +59,7 @@ sub from_col_by_col {
     COL_BY_COL: while( 1 ) {
         my $aoa = [];
         my $col_names;
-        if ( $stmt_type eq 'Create_table' ) {
+        if ( $stmt_type eq 'Create_Table' ) {
             my $col_count;
             my $info = 'CREATE TABLE';
 
@@ -103,7 +103,7 @@ sub from_col_by_col {
             );
             $ax->print_sql_info( $info );
             if ( ! defined $choice ) {
-                if ( $stmt_type eq 'Create_table' && @$aoa == 1 ) {
+                if ( $stmt_type eq 'Create_Table' && @$aoa == 1 ) {
                     next COL_BY_COL;
                 }
                 elsif ( $stmt_type eq 'Insert' && @$aoa == 0 ) {
@@ -117,7 +117,7 @@ sub from_col_by_col {
             }
             elsif ( $choice eq $sf->{i}{ok} ) {
                 if ( ! @$aoa ) {
-                    if ( $stmt_type eq 'Create_table' ) {
+                    if ( $stmt_type eq 'Create_Table' ) {
                         next COL_BY_COL;
                     }
                     elsif ( $stmt_type eq 'Insert' ) {
@@ -161,9 +161,16 @@ sub from_col_by_col {
 
 sub __files_in_dir {
     my ( $sf, $dir ) = @_;
+    my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     if ( ! defined $dir ) {
         return [];
     }
+    if ( ! -d $dir ) {
+        my $message = "Directory '$dir' does not exist.\nThe entry will be removed from history.";
+        $ax->print_error_message( $message );
+        $sf->__remove_from_history( $dir );
+        return [];
+    }
     my $dir_fs = realpath encode( 'locale_fs', $dir );
     my @tmp_files_fs;
     if ( length $sf->{o}{insert}{file_filter} ) {
@@ -213,6 +220,18 @@ sub __add_to_history {
 }
 
 
+sub __remove_from_history {
+    my ( $sf, $dir ) = @_;
+    my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
+    my $h_ref = $ax->read_json( $sf->{i}{f_dir_history} ) // {};
+    my @dirs = @{$h_ref->{dirs}//[]};
+    my $idx = firstidx { $_ eq $dir } @dirs;
+    splice( @dirs, $idx, 1 );
+    $h_ref->{dirs} = \@dirs;
+    $ax->write_json( $sf->{i}{f_dir_history}, $h_ref );
+}
+
+
 sub __new_search_dir {
     my ( $sf ) = @_;
     my $tu = Term::Choose::Util->new( $sf->{i}{tcu_default} );
